@@ -16,6 +16,7 @@ class BFn:
     concat: Final[str] = 'concat'
     convert_from: Final[str] = 'convert_from'
     crypt: Final[str] = 'crypt'
+    clock_timestamp: Final[str] = 'clock_timestamp'
     current_timestamp: Final[str] = 'current_timestamp'
 
     decode: Final[str] = 'decode'
@@ -28,11 +29,6 @@ class BFn:
     icount: Final[str] = 'icount'  # number of elements in array
 
     jsonb_array_length: Final[str] = 'jsonb_array_length'
-
-    lower: Final[str] = 'lower'
-
-    quote_ident: Final[str] = 'quote_ident'
-
     jsonb_agg: Final[str] = 'jsonb_agg'
     jsonb_array_elements: Final[str] = 'jsonb_array_elements'
     jsonb_array_elements_text: Final[str] = 'jsonb_array_elements_text'
@@ -41,27 +37,34 @@ class BFn:
     jsonb_each: Final[str] = 'jsonb_each'
     jsonb_object_agg: Final[str] = 'jsonb_object_agg'
     jsonb_object_keys: Final[str] = 'jsonb_object_keys'
+    jsonb_set: Final[str] = 'jsonb_set'
     jsonb_strip_nulls: Final[str] = 'jsonb_strip_nulls'
 
     length: Final[str] = 'length'
+    lower: Final[str] = 'lower'
 
     nextval: Final[str] = 'nextval'
 
     percentile_cont: Final[str] = 'percentile_cont'
     pg_get_serial_sequence: Final[str] = 'pg_get_serial_sequence'
 
+    quote_ident: Final[str] = 'quote_ident'
+
     regexp_matches: Final[str] = 'regexp_matches'
     replace: Final[str] = 'replace'
+    row_to_json: Final[str] = 'row_to_json'
 
     sha256: Final[str] = 'sha256'
     similarity: Final[str] = 'similarity'
     sort: Final[str] = 'sort'
     sort_asc: Final[str] = 'sort_asc'
     sort_desc: Final[str] = 'sort_desc'
+    statement_timestamp: Final[str] = 'statement_timestamp'
     split_part: Final[str] = 'split_part'
     substring: Final[str] = 'substring'
     sum: Final[str] = 'sum'
 
+    to_jsonb: Final[str] = 'to_jsonb'
     trim: Final[str] = 'trim'
 
     uniq: Final[str] = 'uniq'
