@@ -86,7 +86,7 @@ class ASqlFunction(metaclass=abc.ABCMeta):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def return_type(self) -> FnT:
+    def return_type(self) -> str:
         raise NotImplementedError
 
     @abc.abstractmethod
@@ -121,6 +121,6 @@ class AJsonSqlFunction(ASqlFunction, metaclass=abc.ABCMeta):
             Arg(Arg.input, FnT.JSONB)
         ]
 
-    def return_type(self) -> FnT:
+    def return_type(self) -> str:
         return FnT.JSONB
 
