@@ -43,6 +43,25 @@ array_sort_unique: Final = (
     f" LANGUAGE SQL "
     f" IMMUTABLE;")
 
+is_text_in_array: Final = (
+    f" CREATE OR REPLACE FUNCTION "
+    f" {CFn.is_text_in_array} (    "
+    f"      search_text text, "
+    f"      text_array text[]) "
+    f" RETURNS BOOLEAN "
+    f" AS"
+    f" $$"
+    f" DECLARE"
+    f"  found boolean;"
+    f" BEGIN"
+    f"   SELECT search_text = ANY(text_array) INTO found; "
+    f"   RETURN found;"
+    f" END;"
+    f" $$ "
+    f" LANGUAGE PlPgSQL "
+    f" IMMUTABLE;")
+
+
 if_null_2_empty_bigint_array: Final = (
     f" CREATE OR REPLACE FUNCTION "
     f" {CFn.if_null_2_empty_bigint_array} ("
@@ -87,3 +106,4 @@ def insert_util_fn__general(conn):
     insert_function(array_sort_unique, CFn.array_sort_unique, conn)
     insert_function(if_null_2_empty_bigint_array, CFn.if_null_2_empty_bigint_array, conn)
     insert_function(if_null_2_empty_uuid_array, CFn.if_null_2_empty_uuid_array, conn)
+    insert_function(is_text_in_array, CFn.is_text_in_array, conn)
