@@ -48,11 +48,11 @@ class APFnUpsertTitleDescriptionB64(AJsonPlPgSqlFunction, ABC):
     def body(self) -> str:
         return (
             f" {self._title} := {BFn.convert_from}( "
-            f"      {BFn.decode}( ({Arg.input}->>'{self.input_a_title()}')::{FnT.TEXT.value}, 'base64'), 'UTF-8');"
+            f"      {BFn.decode}( ({Arg.input}->>'{self.input_a_title()}')::{FnT.TEXT}, 'base64'), 'UTF-8');"
             f" {self._des_plain} := {BFn.convert_from}( "
-            f"      {BFn.decode}( ({Arg.input}->>'{CA.DescriptionPlain}')::{FnT.TEXT.value}, 'base64'), 'UTF-8');"
+            f"      {BFn.decode}( ({Arg.input}->>'{CA.DescriptionPlain}')::{FnT.TEXT}, 'base64'), 'UTF-8');"
             f" {self._des_format} := {BFn.convert_from}( "
-            f"      {BFn.decode}( ({Arg.input}->>'{CA.DescriptionFormatted}')::{FnT.TEXT.value}, 'base64'), 'UTF-8');"
+            f"      {BFn.decode}( ({Arg.input}->>'{CA.DescriptionFormatted}')::{FnT.TEXT}, 'base64'), 'UTF-8');"
             f""
             f" {self._title_id} := {self.pfn_title___upsert()}({self._title}); "
             f" {self._description_id} := {self.pfn_description___upsert()}({self._des_format}, {self._des_plain}); "
