@@ -54,17 +54,27 @@ class OpenApiValidation:
 
         validate(req_fix_json, req_schema, resolver=self.ApiComponent)
 
-    def validate_POST_response(self, req, path: str, code: int, attList):
+    def validate_POST_response(self, req, path: str, code, attList):
         self.validate_response(req, path, OAPI.Post, code, attList)
 
-    def validate_GET_response(self, req, path: str, code: int, attList):
+    def validate_GET_response(self, req, path: str, code, attList):
         self.validate_response(req, path, OAPI.Get, code, attList)
 
-    def validate_response(self, res, path: str, method: str, code: int, attList):
+    def validate_response(self, res, path: str, method: str, code: str, attList):
         res_fix = convert_json_by_attributes(res, attList)
         res_fix_json = json.loads(res_fix)
 
-        response_body = self.ApiPath[path][method][OAPI.Responses][code]
+        response_body = self.ApiPath[path][method][OAPI.Responses][str(code)]
+        if '$ref' in response_body.keys():
+            ref_val = response_body['$ref']
+            if ref_val.startswith('#/paths/'):
+                ref = ref_val.split('#/paths/')[1]
+                ref_path = ref.split('/')[0].replace('~1', '/')
+                ref_method = ref.split('/')[1]
+                assert ref.split('/')[2] == 'responses'
+                ref_code = ref.split('/')[3]
+                response_body = self.ApiPath[ref_path][ref_method][OAPI.Responses][str(ref_code)]
+
         res_schema = response_body[OAPI.Content][OAPI.ApplicationJson][OAPI.Schema]
 
         # print("ApiComponent = ", self.ApiComponent)
